<img align="left" width="250" height="250" src="https://i.imgur.com/8jqfpoz.png"> 

[![License](https://img.shields.io/badge/license-MIT-blue.svg)](https://github.com/jdavidrcamacho/gpyrn/blob/master/LICENSE)

[![Build Status](https://app.travis-ci.com/jdavidrcamacho/gpyrn.svg?branch=main)](https://app.travis-ci.com/jdavidrcamacho/gpyrn)


<br/>
<br/>
<br/>
<br/>
<br/>
<br/>
<br/>

***

<br/>

Modelling stellar activity signals in radial velocity data with Gaussian processes regression networks

Check our [wiki page](https://github.com/jdavidrcamacho/gpyrn/wiki) to learn how to install it and use it!

<br/>

***
